@@ -446,6 +446,7 @@ def strip_media_root(file_path: str) -> str:
     :return: str
     """
     if not is_media_path(file_path):
+        logger.error('strip_media_root() expects absolute path under MEDIA_ROOT, got %s', file_path)
         raise ValueError('strip_media_root() expects absolute path under MEDIA_ROOT')
     file_path = file_path[len(settings.MEDIA_ROOT):]
     if file_path.startswith('/'):
@@ -455,14 +456,17 @@ def strip_media_root(file_path: str) -> str:
 
 def get_media_full_path(file_path: str) -> str:
     """
-    Returns the absolute path from a relative path to (settings) MEDIA_ROOT.
+    Returns the absolute path from a (relative) path to (settings) MEDIA_ROOT.
     This enabled stored file names in more portable format for different environment / storage.
-    If MEDIA_ROOT is missing or absolute path is passed to function, exception is raised.
+    If MEDIA_ROOT is missing or non-media path is passed to function, exception is raised.
     Reverse operation of this is strip_media_root().
     :param file_path: str
     :return: str
     """
     if os.path.isabs(file_path) or file_path[:1] in ('.', '/'):
+        if is_media_path(file_path):
+            return file_path
+        logger.error('get_media_full_path() expects relative path to MEDIA_ROOT, got %s', file_path)
         raise ValueError('get_media_full_path() expects relative path to MEDIA_ROOT')
     return os.path.join(settings.MEDIA_ROOT, file_path)
 
